@@ -4,11 +4,13 @@
 # PyMDstat
 # ...
 #
-# Copyright (C) 2013 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
 
 __appname__ = "PyMDstat"
-__version__ = "0.1"
+__version__ = "0.3"
 __author__ = "Nicolas Hennion <nicolas@nicolargo.com>"
 __licence__ = "MIT"
 
-from pymdstat import MdStat
+__all__ = ['MdStat']
+
+from .pymdstat import MdStat
